package pps.core.base.utils;

import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.apache.commons.lang3.StringUtils;
import pps.core.base.entity.BaseEnt;
import pps.core.common.session.PpsUserSession;

import java.util.Collection;
import java.util.Date;

/**
 * 封装工具类
 *
 * @author ZWT
 * @date 2023/08/25 16:08
 */
public class BaseEntUtils {

    /**
     * 设置市电峰谷策略默认值
     *
     * @param entity  实体
     * @param session 会话
     */
    public static void setBaseEntDefault(BaseEnt entity, PpsUserSession session) {
        String id = entity.getId();
        Date now = new Date();
        String userId = session.getId();
        String userName = session.getUserName();
        if (StringUtils.isEmpty(id)) {
            entity.setCreateById(userId);
            entity.setCreateByName(userName);
            entity.setCreateTime(now);
        }
        entity.setModifyById(userId);
        entity.setModifyByName(userName);
        entity.setModifyTime(now);
    }

    /**
     * 批量插入
     *
     * @param mapper      映射器
     * @param entityClass 实体类
     * @param list        列表
     */
    public static <E> void batchInsert(Class<?> mapper, Class<?> entityClass, Collection<E> list) {
        String sqlStatement = SqlHelper.getSqlStatement(mapper, SqlMethod.INSERT_ONE);
        SqlHelper.executeBatch(entityClass, null, list, 1000, (sqlSession, ent) -> {
            sqlSession.insert(sqlStatement, ent);
        });
    }
}
